@@ -1,16 +1,17 @@
 """Loadero test resource.
 
 Test resource is seperated into three parts
-    - TestParams class describes test attributes
+    TestParams class describes test attributes
 
-    - TestAPI class groups API operation with test resources.
+    TestAPI class groups API operation with test resources.
 
-    - Test class combines TestParams and TestAPI.
+    Test class combines TestParams and TestAPI.
 
 Single Test object coresponds to single test in Loadero.
 """
 
 from __future__ import annotations
+from typing import Any
 from datetime import datetime
 from dateutil import parser
 from ..api_client import APIClient
@@ -118,7 +119,7 @@ class Script(Serializable):
 
         return self.to_dict()
 
-    def from_dict(self, json_dict: dict[str, any]) -> Script:
+    def from_dict(self, _: dict[str, Any]) -> Script:
         """Loads script from a dictionary. Never used. Required for
         serialization.
 
@@ -469,11 +470,12 @@ class Test(LoaderoResource):
 
         Required attributes of params field that need to be populated, otherwise
         the method will raise an exception:
-            - name
-            - start_interval
-            - participant_timeout
-            - mode
-            - increment_strategy
+
+        - name
+        - start_interval
+        - participant_timeout
+        - mode
+        - increment_strategy
 
         Raises:
             ValueError: If resource params do not sufficiently identify parent
@@ -493,7 +495,8 @@ class Test(LoaderoResource):
 
         Required attributes of params field that need to be populated, otherwise
         the method will raise an exception:
-            - test_id
+
+        - test_id
 
         Raises:
             ValueError: If resource params do not sufficiently identify
@@ -513,12 +516,13 @@ class Test(LoaderoResource):
 
         Required attributes of params field that need to be populated, otherwise
         the method will raise an exception:
-            - test_id
-            - name
-            - start_interval
-            - participant_timeout
-            - mode
-            - increment_strategy
+
+        - test_id
+        - name
+        - start_interval
+        - participant_timeout
+        - mode
+        - increment_strategy
 
         Raises:
             ValueError: If resource params do not sufficiently identify
@@ -538,7 +542,8 @@ class Test(LoaderoResource):
 
         Required attributes of params field that need to be populated, otherwise
         the method will raise an exception:
-            - test_id
+
+        - test_id
 
         Raises:
             ValueError: If resource params do not sufficiently identify
@@ -558,7 +563,8 @@ class Test(LoaderoResource):
 
         Required attributes of params field that need to be populated, otherwise
         the method will raise an exception:
-            - test_id
+
+        - test_id
 
         Args:
             name (str): New name for the duplicate test.
@@ -582,7 +588,8 @@ class Test(LoaderoResource):
 
         Required attributes of params field that need to be populated, otherwise
         the method will raise an exception:
-            - test_id
+
+        - test_id
 
         Raises:
             ValueError: If resource params do not sufficiently identify
@@ -605,7 +612,8 @@ class Test(LoaderoResource):
 
         Required attributes of params field that need to be populated, otherwise
         the method will raise an exception:
-            - test_id
+
+        - test_id
 
         Args:
             query_params (QueryParams, optional): Describes query parameters
@@ -641,7 +649,8 @@ class Test(LoaderoResource):
 
         Required attributes of params field that need to be populated, otherwise
         the method will raise an exception:
-            - test_id
+
+        - test_id
 
         Args:
             query_params (QueryParams, optional): Describes query parameters
@@ -679,7 +688,8 @@ class Test(LoaderoResource):
 
         Required attributes of params field that need to be populated, otherwise
         the method will raise an exception:
-            - test_id
+
+        - test_id
 
         Args:
             query_params (QueryParams, optional): Describes query parameters
@@ -717,7 +727,8 @@ class Test(LoaderoResource):
 
         Required attributes of params field that need to be populated, otherwise
         the method will raise an exception:
-            - test_id
+
+        - test_id
 
         Args:
             query_params (QueryParams, optional): Describes query parameters
